==> manga_reader-0.0.2.tar.gz: lib/manga_reader.dart <==
library manga_reader;

import 'package:flutter/material.dart';
import 'package:manga_reader/ui/custom_app_bar.dart';
import 'package:manga_reader/ui/custom_bottom_bar.dart';
import 'package:manga_reader/ui/images-scroll_view.dart';
import 'package:manga_reader/model/page_model.dart' as pm;
import 'package:manga_reader/const.dart';

class OnlineMangaReaderWidget extends StatefulWidget {
  final List<pm.Page> pages;
  final String readerTitle;
  VoidCallback onBottom;
  VoidCallback onTop;
  final Widget topWidget, bottomWidget;

  OnlineMangaReaderWidget(this.pages, this.readerTitle,
      {this.onBottom, this.onTop, this.topWidget, this.bottomWidget});

  @override
  _OnlineMangaReaderWidgetState createState() =>
      _OnlineMangaReaderWidgetState();
}

class _OnlineMangaReaderWidgetState extends State<OnlineMangaReaderWidget> {
  bool _showAppbar = true;

  static const Key centerKey = ValueKey('bottom-sliver-list');


  @override
  void dispose() {
    ImagesScrollView.currentPageIndex.value = 0;
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    var imageScrollViewWidget = ImagesScrollView(
      pages: widget.pages,
      onBottom: () => widget.onBottom(),
      onTop: () => widget.onTop(),
      onTap: () => setState(() {
        _showAppbar = !_showAppbar;
      }),
    );

    return Scaffold(
      appBar: PreferredSize(
          child: CustomAppBar(
            title: widget.readerTitle,
            showAppbar: _showAppbar,
          ),
          preferredSize:
              Size(MediaQuery.of(context).size.width, appBarSize(context))),
      extendBodyBehindAppBar: true,
      body: new Stack(
        alignment: Alignment.bottomCenter,
        children: [
          imageScrollViewWidget,
          CustomBottomBar(
              _showAppbar,
              numberTotalPage: widget.pages.length,
              previousButtonPressed: () => widget.onTop(),
              nextButtonPressed: () => widget.onBottom(),
              jumpToPage: (value) => imageScrollViewWidget.jumpToPage(value),
          ),
        ],
      ),
    );
  }
}

==> manga_reader-0.0.8.tar.gz: lib/manga_reader.dart <==
library manga_reader;

import 'package:flutter/material.dart';
import 'package:manga_reader/ui/custom_app_bar.dart';
import 'package:manga_reader/ui/custom_bottom_bar.dart';
import 'package:manga_reader/ui/images-scroll_view.dart';
import 'package:manga_reader/model/page_model.dart' as pm;
import 'package:manga_reader/const.dart';

class OnlineMangaReaderWidget extends StatefulWidget {
  final List<pm.Page> pages;
  final String readerTitle;
  VoidCallback onBottom;
  VoidCallback onTop;
  final Widget topWidget, bottomWidget;

  OnlineMangaReaderWidget(this.pages, this.readerTitle,
      {this.onBottom, this.onTop, this.topWidget, this.bottomWidget});

  @override
  _OnlineMangaReaderWidgetState createState() =>
      _OnlineMangaReaderWidgetState();
}

class _OnlineMangaReaderWidgetState extends State<OnlineMangaReaderWidget> {
  bool _showAppbar = true;

  static const Key centerKey = ValueKey('bottom-sliver-list');


  @override
  void dispose() {
    ImagesScrollView.currentPageIndex.value = 0;
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    var imageScrollViewWidget = ImagesScrollView(
      pages: widget.pages,
      onBottom: () => widget.onBottom(),
      onTop: () => widget.onTop(),
      onTap: () => setState(() {
        _showAppbar = !_showAppbar;
      }),
    );

    return Scaffold(
      appBar: PreferredSize(
          child: CustomAppBar(
            title: widget.readerTitle,
            showAppbar: _showAppbar,
          ),
          preferredSize:
              Size(MediaQuery.of(context).size.width, appBarSize(context))),
      extendBodyBehindAppBar: true,
      body: new Stack(
        alignment: Alignment.bottomCenter,
        children: [
          InteractiveViewer(
            boundaryMargin: EdgeInsets.zero,
            panEnabled: true,
            scaleEnabled: true,
            minScale: 1.0,
            maxScale: 4,
            child: imageScrollViewWidget,
          ),
          CustomBottomBar(
              _showAppbar,
              numberTotalPage: widget.pages.length,
              previousButtonPressed: () => widget.onTop(),
              nextButtonPressed: () => widget.onBottom(),
              jumpToPage: (value) => imageScrollViewWidget.jumpToPage(value),
          ),
        ],
      ),
    );
  }
}
